/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.util.DateTime;

/**
 * Model definition for Community.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Community extends GenericJson {

  /**
   * The category of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String category;

  /**
   * The co-owners of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("co_owners")
  private java.util.List<OrkutAuthorResource> coOwners;

  static {
    // hack to force ProGuard to consider OrkutAuthorResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutAuthorResource.class);
  }

  /**
   * The time the community was created, in RFC 3339 format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("creation_date")
  private DateTime creationDate;

  /**
   * The description of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String description;

  /**
   * The id of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer id;

  /**
   * Identifies this resource as a community. Value: "orkut#community"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The official language of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String language;

  /**
   * List of resources for the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * The location of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String location;

  /**
   * The number of users who are part of the community. This number may be approximate, so do not
   * rely on it for iteration.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("member_count")
  private Integer memberCount;

  /**
   * The list of moderators of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutAuthorResource> moderators;

  static {
    // hack to force ProGuard to consider OrkutAuthorResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutAuthorResource.class);
  }

  /**
   * The name of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * The person who owns the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource owner;

  /**
   * The photo of the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key("photo_url")
  private String photoUrl;

  /**
   * The category of the community.
   * The value returned may be {@code null}.
   */
  public String getCategory() {
    return category;
  }

  /**
   * The category of the community.
   * The value set may be {@code null}.
   */
  public Community setCategory(String category) {
    this.category = category;
    return this;
  }

  /**
   * The co-owners of the community.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutAuthorResource> getCoOwners() {
    return coOwners;
  }

  /**
   * The co-owners of the community.
   * The value set may be {@code null}.
   */
  public Community setCoOwners(java.util.List<OrkutAuthorResource> coOwners) {
    this.coOwners = coOwners;
    return this;
  }

  /**
   * The time the community was created, in RFC 3339 format.
   * The value returned may be {@code null}.
   */
  public DateTime getCreationDate() {
    return creationDate;
  }

  /**
   * The time the community was created, in RFC 3339 format.
   * The value set may be {@code null}.
   */
  public Community setCreationDate(DateTime creationDate) {
    this.creationDate = creationDate;
    return this;
  }

  /**
   * The description of the community.
   * The value returned may be {@code null}.
   */
  public String getDescription() {
    return description;
  }

  /**
   * The description of the community.
   * The value set may be {@code null}.
   */
  public Community setDescription(String description) {
    this.description = description;
    return this;
  }

  /**
   * The id of the community.
   * The value returned may be {@code null}.
   */
  public Integer getId() {
    return id;
  }

  /**
   * The id of the community.
   * The value set may be {@code null}.
   */
  public Community setId(Integer id) {
    this.id = id;
    return this;
  }

  /**
   * Identifies this resource as a community. Value: "orkut#community"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as a community. Value: "orkut#community"
   * The value set may be {@code null}.
   */
  public Community setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The official language of the community.
   * The value returned may be {@code null}.
   */
  public String getLanguage() {
    return language;
  }

  /**
   * The official language of the community.
   * The value set may be {@code null}.
   */
  public Community setLanguage(String language) {
    this.language = language;
    return this;
  }

  /**
   * List of resources for the community.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * List of resources for the community.
   * The value set may be {@code null}.
   */
  public Community setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * The location of the community.
   * The value returned may be {@code null}.
   */
  public String getLocation() {
    return location;
  }

  /**
   * The location of the community.
   * The value set may be {@code null}.
   */
  public Community setLocation(String location) {
    this.location = location;
    return this;
  }

  /**
   * The number of users who are part of the community. This number may be approximate, so do not
   * rely on it for iteration.
   * The value returned may be {@code null}.
   */
  public Integer getMemberCount() {
    return memberCount;
  }

  /**
   * The number of users who are part of the community. This number may be approximate, so do not
   * rely on it for iteration.
   * The value set may be {@code null}.
   */
  public Community setMemberCount(Integer memberCount) {
    this.memberCount = memberCount;
    return this;
  }

  /**
   * The list of moderators of the community.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutAuthorResource> getModerators() {
    return moderators;
  }

  /**
   * The list of moderators of the community.
   * The value set may be {@code null}.
   */
  public Community setModerators(java.util.List<OrkutAuthorResource> moderators) {
    this.moderators = moderators;
    return this;
  }

  /**
   * The name of the community.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * The name of the community.
   * The value set may be {@code null}.
   */
  public Community setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * The person who owns the community.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getOwner() {
    return owner;
  }

  /**
   * The person who owns the community.
   * The value set may be {@code null}.
   */
  public Community setOwner(OrkutAuthorResource owner) {
    this.owner = owner;
    return this;
  }

  /**
   * The photo of the community.
   * The value returned may be {@code null}.
   */
  public String getPhotoUrl() {
    return photoUrl;
  }

  /**
   * The photo of the community.
   * The value set may be {@code null}.
   */
  public Community setPhotoUrl(String photoUrl) {
    this.photoUrl = photoUrl;
    return this;
  }

}
