/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for CommunityMessage.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CommunityMessage extends GenericJson {

  /**
   * The timestamp of the date when the message was added, in RFC 3339 format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime addedDate;

  /**
   * The creator of the message. If ommited, the message is annonimous.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource author;

  /**
   * The body of the message.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String body;

  /**
   * The ID of the message.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * Whether this post was marked as spam by the viewer, when he/she is not the community owner or
   * one of its moderators.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isSpam;

  /**
   * Identifies this resource as a community message. Value: "orkut#communityMessage"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * List of resources for the community message.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * The subject of the message.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String subject;

  /**
   * The timestamp of the date when the message was added, in RFC 3339 format.
   * The value returned may be {@code null}.
   */
  public DateTime getAddedDate() {
    return addedDate;
  }

  /**
   * The timestamp of the date when the message was added, in RFC 3339 format.
   * The value set may be {@code null}.
   */
  public CommunityMessage setAddedDate(DateTime addedDate) {
    this.addedDate = addedDate;
    return this;
  }

  /**
   * The creator of the message. If ommited, the message is annonimous.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getAuthor() {
    return author;
  }

  /**
   * The creator of the message. If ommited, the message is annonimous.
   * The value set may be {@code null}.
   */
  public CommunityMessage setAuthor(OrkutAuthorResource author) {
    this.author = author;
    return this;
  }

  /**
   * The body of the message.
   * The value returned may be {@code null}.
   */
  public String getBody() {
    return body;
  }

  /**
   * The body of the message.
   * The value set may be {@code null}.
   */
  public CommunityMessage setBody(String body) {
    this.body = body;
    return this;
  }

  /**
   * The ID of the message.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of the message.
   * The value set may be {@code null}.
   */
  public CommunityMessage setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * Whether this post was marked as spam by the viewer, when he/she is not the community owner or
   * one of its moderators.
   * The value returned may be {@code null}.
   */
  public Boolean getIsSpam() {
    return isSpam;
  }

  /**
   * Whether this post was marked as spam by the viewer, when he/she is not the community owner or
   * one of its moderators.
   * The value set may be {@code null}.
   */
  public CommunityMessage setIsSpam(Boolean isSpam) {
    this.isSpam = isSpam;
    return this;
  }

  /**
   * Identifies this resource as a community message. Value: "orkut#communityMessage"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as a community message. Value: "orkut#communityMessage"
   * The value set may be {@code null}.
   */
  public CommunityMessage setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * List of resources for the community message.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * List of resources for the community message.
   * The value set may be {@code null}.
   */
  public CommunityMessage setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * The subject of the message.
   * The value returned may be {@code null}.
   */
  public String getSubject() {
    return subject;
  }

  /**
   * The subject of the message.
   * The value set may be {@code null}.
   */
  public CommunityMessage setSubject(String subject) {
    this.subject = subject;
    return this;
  }

}
