/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.orkut.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * Model definition for CommunityTopic.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Orkut API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class CommunityTopic extends GenericJson {

  /**
   * The creator of the topic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private OrkutAuthorResource author;

  /**
   * The body of the topic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String body;

  /**
   * The ID of the topic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key @JsonString
  private Long id;

  /**
   * Whether the topic is closed for new messages.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Boolean isClosed;

  /**
   * Identifies this resource as a community topic. Value: "orkut#communityTopic"
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The timestamp of the last update, in RFC 3339 format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private DateTime lastUpdate;

  /**
   * Snippet of the last message posted on this topic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String latestMessageSnippet;

  /**
   * List of resources for the community.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OrkutLinkResource> links;

  static {
    // hack to force ProGuard to consider OrkutLinkResource used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OrkutLinkResource.class);
  }

  /**
   * Most recent messages.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<CommunityMessage> messages;

  static {
    // hack to force ProGuard to consider CommunityMessage used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(CommunityMessage.class);
  }

  /**
   * The total number of replies this topic has received.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Integer numberOfReplies;

  /**
   * The title of the topic.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String title;

  /**
   * The creator of the topic.
   * The value returned may be {@code null}.
   */
  public OrkutAuthorResource getAuthor() {
    return author;
  }

  /**
   * The creator of the topic.
   * The value set may be {@code null}.
   */
  public CommunityTopic setAuthor(OrkutAuthorResource author) {
    this.author = author;
    return this;
  }

  /**
   * The body of the topic.
   * The value returned may be {@code null}.
   */
  public String getBody() {
    return body;
  }

  /**
   * The body of the topic.
   * The value set may be {@code null}.
   */
  public CommunityTopic setBody(String body) {
    this.body = body;
    return this;
  }

  /**
   * The ID of the topic.
   * The value returned may be {@code null}.
   */
  public Long getId() {
    return id;
  }

  /**
   * The ID of the topic.
   * The value set may be {@code null}.
   */
  public CommunityTopic setId(Long id) {
    this.id = id;
    return this;
  }

  /**
   * Whether the topic is closed for new messages.
   * The value returned may be {@code null}.
   */
  public Boolean getIsClosed() {
    return isClosed;
  }

  /**
   * Whether the topic is closed for new messages.
   * The value set may be {@code null}.
   */
  public CommunityTopic setIsClosed(Boolean isClosed) {
    this.isClosed = isClosed;
    return this;
  }

  /**
   * Identifies this resource as a community topic. Value: "orkut#communityTopic"
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Identifies this resource as a community topic. Value: "orkut#communityTopic"
   * The value set may be {@code null}.
   */
  public CommunityTopic setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The timestamp of the last update, in RFC 3339 format.
   * The value returned may be {@code null}.
   */
  public DateTime getLastUpdate() {
    return lastUpdate;
  }

  /**
   * The timestamp of the last update, in RFC 3339 format.
   * The value set may be {@code null}.
   */
  public CommunityTopic setLastUpdate(DateTime lastUpdate) {
    this.lastUpdate = lastUpdate;
    return this;
  }

  /**
   * Snippet of the last message posted on this topic.
   * The value returned may be {@code null}.
   */
  public String getLatestMessageSnippet() {
    return latestMessageSnippet;
  }

  /**
   * Snippet of the last message posted on this topic.
   * The value set may be {@code null}.
   */
  public CommunityTopic setLatestMessageSnippet(String latestMessageSnippet) {
    this.latestMessageSnippet = latestMessageSnippet;
    return this;
  }

  /**
   * List of resources for the community.
   * The value returned may be {@code null}.
   */
  public java.util.List<OrkutLinkResource> getLinks() {
    return links;
  }

  /**
   * List of resources for the community.
   * The value set may be {@code null}.
   */
  public CommunityTopic setLinks(java.util.List<OrkutLinkResource> links) {
    this.links = links;
    return this;
  }

  /**
   * Most recent messages.
   * The value returned may be {@code null}.
   */
  public java.util.List<CommunityMessage> getMessages() {
    return messages;
  }

  /**
   * Most recent messages.
   * The value set may be {@code null}.
   */
  public CommunityTopic setMessages(java.util.List<CommunityMessage> messages) {
    this.messages = messages;
    return this;
  }

  /**
   * The total number of replies this topic has received.
   * The value returned may be {@code null}.
   */
  public Integer getNumberOfReplies() {
    return numberOfReplies;
  }

  /**
   * The total number of replies this topic has received.
   * The value set may be {@code null}.
   */
  public CommunityTopic setNumberOfReplies(Integer numberOfReplies) {
    this.numberOfReplies = numberOfReplies;
    return this;
  }

  /**
   * The title of the topic.
   * The value returned may be {@code null}.
   */
  public String getTitle() {
    return title;
  }

  /**
   * The title of the topic.
   * The value set may be {@code null}.
   */
  public CommunityTopic setTitle(String title) {
    this.title = title;
    return this;
  }

}
